.. Geothermal Play Fairway Analysis documentation master file, created by
   sphinx-quickstart on Wed Apr 16 10:40:11 2025.

Geothermal Play Fairway Analysis documentation
==============================================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

    API reference <_autosummary/geoPFA>


What is geoPFA?
---------------

.. include:: ../README.md
   :end-before: NOTICE

